@@ -42,17 +42,11 @@ class TempFile(File):
             pass
 
 
-class NamedTempFile(TempFile):
-
-    def __init__(self, extension):
-        self.name = os.path.join(gettempdir(), str(uuid.uuid4()))
-        super().__init__(self.name + "." + extension)
-
-
-class ShapeTempFile(NamedTempFile):
+class ShapeTempFile(TempFile):
 
     def __init__(self):
-        super().__init__("shp")
+        self.name = os.path.join(gettempdir(), str(uuid.uuid4()))
+        super().__init__(self.name + ".shp")
 
     def __del__(self):
         super().__del__()
